# CanvasList

A list view that displays all data instances, which is useful for exploring data with Canvas's built in filters and grouping interactions.

## Installation

```bash
pip install canvas_list
```


## Usage

To learn how to use Canvas, see the [documentation](https://satishlokkoju.github.io/deepview/).
